summaryrefslogtreecommitdiffstats
path: root/chromium/base/files/file.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2022-02-04 17:20:24 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2022-02-12 08:15:25 +0000
commit8fa0776f1f79e91fc9c0b9c1ba11a0a29c05196b (patch)
tree788d8d7549712682703a0310ca4a0f0860d4802b /chromium/base/files/file.h
parent606d85f2a5386472314d39923da28c70c60dc8e7 (diff)
BASELINE: Update Chromium to 98.0.4758.90
Change-Id: Ib7c41539bf8a8e0376bd639f27d68294de90f3c8 Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
Diffstat (limited to 'chromium/base/files/file.h')
-rw-r--r--chromium/base/files/file.h27
1 files changed, 13 insertions, 14 deletions
diff --git a/chromium/base/files/file.h b/chromium/base/files/file.h
index 69c5d90b982..bd35a82f582 100644
--- a/chromium/base/files/file.h
+++ b/chromium/base/files/file.h
@@ -50,8 +50,6 @@ class BASE_EXPORT File {
// a file.
// FLAG_(WRITE|APPEND) are mutually exclusive. This is so that APPEND behavior
// will be consistent with O_APPEND on POSIX.
- // FLAG_EXCLUSIVE_(READ|WRITE) only grant exclusive access to the file on
- // creation on POSIX; for existing files, consider using Lock().
enum Flags {
FLAG_OPEN = 1 << 0, // Opens a file, only if it exists.
FLAG_CREATE = 1 << 1, // Creates a new file, only if it does not
@@ -63,18 +61,19 @@ class BASE_EXPORT File {
FLAG_READ = 1 << 5,
FLAG_WRITE = 1 << 6,
FLAG_APPEND = 1 << 7,
- FLAG_EXCLUSIVE_READ = 1 << 8, // Windows only. Opposite of Windows SHARE.
- FLAG_EXCLUSIVE_WRITE = 1 << 9, // Windows only. Opposite of Windows SHARE.
+ FLAG_WIN_EXCLUSIVE_READ = 1 << 8, // Windows only. Opposite of SHARE.
+ FLAG_WIN_EXCLUSIVE_WRITE = 1 << 9, // Windows only. Opposite of SHARE.
FLAG_ASYNC = 1 << 10,
- FLAG_TEMPORARY = 1 << 11, // Windows only.
- FLAG_HIDDEN = 1 << 12, // Windows only.
+ FLAG_WIN_TEMPORARY = 1 << 11, // Windows only.
+ FLAG_WIN_HIDDEN = 1 << 12, // Windows only.
FLAG_DELETE_ON_CLOSE = 1 << 13,
- FLAG_WRITE_ATTRIBUTES = 1 << 14, // Windows only.
- FLAG_SHARE_DELETE = 1 << 15, // Windows only.
- FLAG_TERMINAL_DEVICE = 1 << 16, // Serial port flags.
- FLAG_BACKUP_SEMANTICS = 1 << 17, // Windows only.
- FLAG_EXECUTE = 1 << 18, // Windows only.
- FLAG_SEQUENTIAL_SCAN = 1 << 19, // Windows only.
+ FLAG_WRITE_ATTRIBUTES = 1 << 14, // File opened in a mode allowing writing
+ // attributes, such as with SetTimes().
+ FLAG_WIN_SHARE_DELETE = 1 << 15, // Windows only.
+ FLAG_TERMINAL_DEVICE = 1 << 16, // Serial port flags.
+ FLAG_WIN_BACKUP_SEMANTICS = 1 << 17, // Windows only.
+ FLAG_WIN_EXECUTE = 1 << 18, // Windows only.
+ FLAG_WIN_SEQUENTIAL_SCAN = 1 << 19, // Windows only.
FLAG_CAN_DELETE_ON_CLOSE = 1 << 20, // Requests permission to delete a file
// via DeleteOnClose() (Windows only).
// See DeleteOnClose() for details.
@@ -337,11 +336,11 @@ class BASE_EXPORT File {
// calling DeleteOnClose(true).
//
// In all cases, all pre-existing handles to the file must have been opened
// with FLAG_SHARE_DELETE. Once the disposition has been set by any of the
// above means, no new File objects can be created for the file.
//
// So:
// - Use FLAG_SHARE_DELETE when creating/opening a file to allow another
// entity on the system to cause it to be deleted when it is closed. (Note:
// another entity can delete the file the moment after it is closed, so not
// using this permission doesn't provide any protections.)
@@ -337,11 +336,11 @@ class BASE_EXPORT File {
//
// In all cases, all pre-existing handles to the file must have been opened
- // with FLAG_SHARE_DELETE. Once the disposition has been set by any of the
+ // with FLAG_WIN_SHARE_DELETE. Once the disposition has been set by any of the
// above means, no new File objects can be created for the file.
//
@@ -337,11 +336,11 @@ class BASE_EXPORT File {
//
// So:
- // - Use FLAG_SHARE_DELETE when creating/opening a file to allow another
+ // - Use FLAG_WIN_SHARE_DELETE when creating/opening a file to allow another
// entity on the system to cause it to be deleted when it is closed. (Note:
// another entity can delete the file the moment after it is closed, so not